@@ -274,6 +274,25 @@ Query the exchange and currency for all listings of AAPL and format for
 terminal display:
 
     quantrocket master get --symbols AAPL --fields Exchange Currency | csvlook -I
+
+Notes:
+
+Parameters for filtering query results are combined according to the following
+rules. First, the master service determines what to include in the result set,
+based on the inclusion filters: `--exchanges`, `--sec-types`, `--currencies`,
+`--universes`, `--symbols`, and `--sids`. With the exception of `--sids`, these
+parameters are ANDed together. That is, securities must satisfy all of the
+parameters to be included. If `--vendors` is provided, only those vendors are
+searched for the purpose of determining matches.
+
+The `--sids` parameter is treated differently. Securities matching `--sids` are
+always included, regardless of whether they meet the other inclusion criteria.
+
+After determining what to include, the master service then applies the exclusion
+filters (`--exclude-sids`, `--exclude-universes`, `--exclude-delisted`,
+`--exclude-expired`, and `--frontmonth`) to determine what (if anything) should be
+removed from the result set. Exclusion filters are ORed, that is, securities are
+excluded if they match any of the exclusion criteria.
     """
     parser = _subparsers.add_parser(
         "get",
@@ -578,6 +597,11 @@ Copy a universe but exclude delisted securities:
         dest="infilepath_or_buffer",
         help="create the universe from the sids in this file (specify '-' to read file "
         "from stdin)")
+    parser.add_argument(
+        "-i", "--sids",
+        nargs="*",
+        metavar="SID",
+        help="create the universe from these sids")
     parser.add_argument(
         "--from-universes",
         nargs="*",
