@@ -29,8 +29,8 @@ EOD_AGGREGATE_RESULTS = {
         ('Commission', '2016-03-18'): 0.0,
         ('NetExposure', '2016-03-17'): 1.0,
         ('NetExposure', '2016-03-18'): 1.0,
-        ('Return', '2016-03-17'): -0.006873687065956036,
-        ('Return', '2016-03-18'): -0.0010547573032254989,
+        ('Return', '2016-03-17'): -0.006873687065956,
+        ('Return', '2016-03-18'): -0.0010547573032254,
         ('Slippage', '2016-03-17'): 0.0,
         ('Slippage', '2016-03-18'): 0.0,
         ('TotalHoldings', '2016-03-17'): 3.0,
@@ -46,8 +46,8 @@ EOD_DETAILED_RESULTS = {
         ('AbsWeight', '2016-03-18'): 0.0,
         ('Commission', '2016-03-17'): 0.0,
         ('Commission', '2016-03-18'): 0.0,
-        ('LMavg', '2016-03-17'): 116.45881666666641,
-        ('LMavg', '2016-03-18'): 116.43891666666642,
+        ('LMavg', '2016-03-17'): 116.4588166666664,
+        ('LMavg', '2016-03-18'): 116.43891666666641,
         ('NetExposure', '2016-03-17'): 0.0,
         ('NetExposure', '2016-03-18'): 0.0,
         ('Return', '2016-03-17'): -0.0,
@@ -73,8 +73,8 @@ EOD_DETAILED_RESULTS = {
         ('LMavg', '2016-03-18'): 496.5921499999994,
         ('NetExposure', '2016-03-17'): 0.3333333333333333,
         ('NetExposure', '2016-03-18'): 0.3333333333333333,
-        ('Return', '2016-03-17'): -0.008608029904632497,
-        ('Return', '2016-03-18'): -0.0043853377186710745,
+        ('Return', '2016-03-17'): -0.0086080299046324,
+        ('Return', '2016-03-18'): -0.004385337718671,
         ('Signal', '2016-03-17'): 1.0,
         ('Signal', '2016-03-18'): 1.0,
         ('Slippage', '2016-03-17'): 0.0,
@@ -122,9 +122,9 @@ INTRADAY_AGGREGATE_RESULTS = {
         ('Return', '2018-12-18', '09:00:00'): 0.0,
         ('Return', '2018-12-18', '10:00:00'): 0.0,
         ('Return', '2018-12-18', '11:00:00'): 0.0,
-        ('Return', '2018-12-19', '09:00:00'): 0.0010389911773893924,
-        ('Return', '2018-12-19', '10:00:00'): -0.0004370168394709274,
-        ('Return', '2018-12-19', '11:00:00'): -1.9934242843433506e-05,
+        ('Return', '2018-12-19', '09:00:00'): 0.0010389911773893,
+        ('Return', '2018-12-19', '10:00:00'): -0.0004370168394709,
+        ('Return', '2018-12-19', '11:00:00'): -1.9934242843433502e-05,
         ('Slippage', '2018-12-18', '09:00:00'): 0.00001,
         ('Slippage', '2018-12-18', '10:00:00'): 0.00002,
         ('Slippage', '2018-12-18', '11:00:00'): 0.00001,
@@ -186,8 +186,8 @@ INTRADAY_DETAILED_RESULTS = {
         ('Return', '2018-12-18', '09:00:00'): -0.0,
         ('Return', '2018-12-18', '10:00:00'): -0.0,
         ('Return', '2018-12-18', '11:00:00'): -0.0,
-        ('Return', '2018-12-19', '09:00:00'): 0.0004902863658290624,
-        ('Return', '2018-12-19', '10:00:00'): -0.00014348896928548794,
+        ('Return', '2018-12-19', '09:00:00'): 0.000490286365829,
+        ('Return', '2018-12-19', '10:00:00'): -0.0001434889692854,
         ('Return', '2018-12-19', '11:00:00'): 1.0506730874437764e-05,
         ('Signal', '2018-12-18', '09:00:00'): 0.0,
         ('Signal', '2018-12-18', '10:00:00'): 0.0,
@@ -259,9 +259,9 @@ INTRADAY_DETAILED_RESULTS = {
         ('Return', '2018-12-18', '09:00:00'): -0.0,
         ('Return', '2018-12-18', '10:00:00'): -0.0,
         ('Return', '2018-12-18', '11:00:00'): 0.0,
-        ('Return', '2018-12-19', '09:00:00'): 0.0007272756081426303,
-        ('Return', '2018-12-19', '10:00:00'): -0.0004057355535645791,
-        ('Return', '2018-12-19', '11:00:00'): 0.0003899498918343625,
+        ('Return', '2018-12-19', '09:00:00'): 0.0007272756081426,
+        ('Return', '2018-12-19', '10:00:00'): -0.0004057355535645,
+        ('Return', '2018-12-19', '11:00:00'): 0.0003899498918343,
         ('Signal', '2018-12-18', '09:00:00'): 0.0,
         ('Signal', '2018-12-18', '10:00:00'): 0.0,
         ('Signal', '2018-12-18', '11:00:00'): 0.0,
@@ -299,6 +299,9 @@ class ReadMoonshotCsvTestCase(unittest.TestCase):
     Test cases for `quantrocket.moonshot.read_moonshot_csv`.
     """
 
+    def setUp(self):
+        self.maxDiff = None
+
     def tearDown(self):
         if os.path.exists("results.csv"):
             os.remove("results.csv")
